==> haskell-microlens-mtl-0.2.0.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-mtl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-mtl
version:              0.2.0.1
visibility:           public
id:                   microlens-mtl-0.2.0.1-9oi5AGxgvu6872DSJa0Xzd
key:                  microlens-mtl-0.2.0.1-9oi5AGxgvu6872DSJa0Xzd
license:              BSD-3-Clause
maintainer:           Monadfix <hi@monadfix.io>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/monadfix/microlens
synopsis:             microlens support for Reader/Writer/State from mtl
description:
    This package contains functions (like '\''view'\'' or '\''+='\'') which work on '\''MonadReader'\'', '\''MonadWriter'\'', and '\''MonadState'\'' from the mtl package.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.

category:             Data, Lenses
abi:                  9fcf7ef8ca99b3de733d06276ef7af34
exposed:              True
exposed-modules:      Lens.Micro.Mtl Lens.Micro.Mtl.Internal
import-dirs:          /usr/lib/ghc-8.10.3/site-local/microlens-mtl-0.2.0.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/microlens-mtl-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/microlens-mtl-0.2.0.1
hs-libraries:         HSmicrolens-mtl-0.2.0.1-9oi5AGxgvu6872DSJa0Xzd
depends:
    base-4.14.1.0 microlens-0.4.11.2-9caS3Frz8K54yIHXMtlddL mtl-2.2.2
    transformers-0.5.6.2
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM

haddock-interfaces:
    /usr/share/doc/haskell-microlens-mtl/html/microlens-mtl.haddock

haddock-html:         /usr/share/doc/haskell-microlens-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-mtl-0.2.0.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-mtl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-mtl
version:              0.2.0.1
visibility:           public
id:                   microlens-mtl-0.2.0.1-3tNQgwbNspG9ZtqGot68nU
key:                  microlens-mtl-0.2.0.1-3tNQgwbNspG9ZtqGot68nU
license:              BSD-3-Clause
maintainer:           Monadfix <hi@monadfix.io>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/monadfix/microlens
synopsis:             microlens support for Reader/Writer/State from mtl
description:
    This package contains functions (like '\''view'\'' or '\''+='\'') which work on '\''MonadReader'\'', '\''MonadWriter'\'', and '\''MonadState'\'' from the mtl package.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.

category:             Data, Lenses
abi:                  38c3d5149ae73570e025b90b21c34ef1
exposed:              True
exposed-modules:      Lens.Micro.Mtl Lens.Micro.Mtl.Internal
import-dirs:          /usr/lib/ghc-8.10.3/site-local/microlens-mtl-0.2.0.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/microlens-mtl-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/microlens-mtl-0.2.0.1
hs-libraries:         HSmicrolens-mtl-0.2.0.1-3tNQgwbNspG9ZtqGot68nU
depends:
    base-4.14.1.0 microlens-0.4.12.0-LWmCgM3D0eIxbRgAEzd8k mtl-2.2.2
    transformers-0.5.6.2
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM

haddock-interfaces:
    /usr/share/doc/haskell-microlens-mtl/html/microlens-mtl.haddock

haddock-html:         /usr/share/doc/haskell-microlens-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
